pub enum Error {
Show 18 variants
CryptoError(UnpadError),
InvalidBlockHash,
InvalidBlockId(u32),
InvalidDbSignature([u8; 4]),
InvalidFinalBlockHash([u8; 32]),
InvalidHeaderHash,
InvalidHeaderSize {
id: u8,
expected: u16,
actual: u16,
},
InvalidKey,
InvalidKeyFile,
Io(Error),
MissingHeader(u8),
UnhandledCompression(u32),
UnhandledDbType([u8; 4]),
UnhandledHeader(u8),
UnhandledMasterCipher([u8; 16]),
UnhandledStreamCipher(u32),
Unimplemented(String),
XmlError(String),
}Expand description
Error type for database errors.
Variants
CryptoError(UnpadError)
Error during the encryption or decryption of the database.
InvalidBlockHash
The hash of a data block is invalid.
InvalidBlockId(u32)
The data block has an invalid identifier.
InvalidDbSignature([u8; 4])
The database signature is invalid.
InvalidFinalBlockHash([u8; 32])
The hash of the final data block is invalid.
InvalidHeaderHash
The header hash is invalid (doesn’t match expected hash).
InvalidHeaderSize
The size of a header is invalid
InvalidKey
The key (user’s password and key file) is invalid.
InvalidKeyFile
The key file is invalid.
Io(Error)
An I/O error has occurred.
MissingHeader(u8)
The supplied header is missing.
UnhandledCompression(u32)
The compression algorithm specified in the headers is not supported.
UnhandledDbType([u8; 4])
The database type specified in the headers is not supported.
UnhandledHeader(u8)
The header type used in the headers is not supported.
UnhandledMasterCipher([u8; 16])
The master encryption algorithm is not supported.
UnhandledStreamCipher(u32)
The stream encryption algorithm is not supported.
Unimplemented(String)
The specified functionality is not yet supported.
XmlError(String)
The XML contains the specified error.