CompositeKey

Struct CompositeKey 

pub struct CompositeKey(/* private fields */);
Composition of the user’s key data.

This data type uses secstr’s SecStr to protect the key data. To retrieve the protected data use the unsecure method.

Implementations

Source

impl CompositeKey

pub fn from_both<S: Into<String>>( password: S, key_file: KeyFile, ) -> CompositeKey

Create a composite key from both a password and a key file.

Examples
use kpdb::{CompositeKey, KeyFile};
use std::fs::File;

let mut file = File::open("database.key")?;
let key_file = KeyFile::open(&mut file)?;
let key = CompositeKey::from_both("secret", key_file);
pub fn from_key_file(key_file: KeyFile) -> CompositeKey

Create a composite key from a key file.

Examples
use kpdb::{CompositeKey, KeyFile};
use std::fs::File;

let mut file = File::open("database.key")?;
let key_file = KeyFile::open(&mut file)?;
let key = CompositeKey::from_key_file(key_file);
pub fn from_password<S: Into<String>>(password: S) -> CompositeKey

Create a composite key from a password.

Examples
use kpdb::CompositeKey;

let key = CompositeKey::from_password("secret");
pub fn unsecure(&self) -> [u8; 32]

Gets the protected data from this composite key.